# Functions
All my personal functions that might be reusable later
Here is what you can find in this repo :
- `general.py` : useful general functions I wrote and think might be reusable in all kinf of project
- `secundary.py` : other functions that I wrote but more understable in their own context and then less 'generalizable'
- `serie_gestion.py` : aims to collect manipulation on pandas.Series. Get a Series and send another one of same length. These functions can easily be `piped`
- `ts_analysis.py` : class whiwh allow to manipulate time series. Useful for cross-val in time Series. Documentation should come later about it.
- `time_format.py` : set of functions to manipulate time values and make conversions (ISO, pandas, time, datetime)
- `slack.py` : script to easily send messages on a slack channel (I created a personnal env where I have a channel per project)